import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, arc, pie, scaleBand, scaleLinear, max, format } from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';
//import { Spring } from 'react-spring';

const width = 960;
const height = 500;
const margin = { top: 20, right: 30, bottom: 65, left: 220 };
const xAxisLabelOffset = 50;

let yearToggle = 2019;

function getRandomInt(max) {
  return Math.floor(Math.random() * Math.floor(max));
}


const App = () => {
  const data = useData();
  let [randomVal, setRandomVal] = useState(1);
  //let [randomVals, setRandomVals] = useState([0,0,0,0,0, 0,0,0,0,0]);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const yValue = d => d.Country;
  const countryCode = d => d.CountryCode;
  const id = d => d.CountryCode % 10; // ideally would map the country code to [1,10]
  const xValue2010 = d => d.Population2010;
  const xValue2020 = d => d.Population2020;
  let flag = true;
  let xValue = xValue2010;
  let target;

  const siFormat = format('.2s');
  const xAxisTickFormat = tickValue => siFormat(tickValue).replace('G', 'B');

  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .paddingInner(0.15);

  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);

  
  const toggleYear = () => {
		console.log("toggle");
    // if (target === undefined) {
    //   target = [0,0,0,0,0, 0,0,0,0,0];
    // }
    if (target === undefined || randomVal === target) {
      target = getRandomInt(80) - 40; // -40 to 40ish range
    }
    if (target > randomVal) {
      randomVal++;
    } else {
      randomVal--;
    }
    console.log(target + " " +  randomVal);
    
    // for (let i = 0; i < 10; i++) {
    //   if (randomVals[i] === target[i]) {
    //     target[i] = getRandomInt(80) - 40; // -40 to 40ish range
    //   }
    //   if (target[i] > randomVals[i]) {
    //     randomVals[i] = randomVals[i] + 1;
    //   } else {
    //     randomVals[i] = randomVals[i] - 1;
    //   }
    // }
    // setRandomVals(randomVals);
    setRandomVal(randomVal);
  };
  
  

  
  return (
    <svg width={width} height={height} onMouseMove={toggleYear}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          tickFormat={xAxisTickFormat}
        />
        <AxisLeft yScale={yScale} />
        <text
          className="axis-label"
          x={innerWidth / 2}
          y={innerHeight + xAxisLabelOffset}
          textAnchor="middle"
        >
          Population
        </text>
        <Marks
          data={data}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          randomVal={randomVal}
          id={id}
          tooltipFormat={xAxisTickFormat}
        />
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
